@@ -9,4 +9,8 @@ get.data.frame.from.formula <- function(formula, data) {
 			d[[i]] = factor(d[[i]])
 	}
 	return(d)
-}
\ No newline at end of file
+}
+
+entropyHelper <- function(x) {
+    return(entropy(table(x, useNA="always")))
+}
